#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-EF7APpOHwSFJ4CQly64cGD
key:                  pantry-0.8.3-EF7APpOHwSFJ4CQly64cGD
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  9f20e9b625e88de132e7f474085fb4a7
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-EF7APpOHwSFJ4CQly64cGD
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-GWc1LmCE0o9Bpe9MYCbSNj
    ansi-terminal-1.1-FMAjddYCnoo35p0Ajg6Jk8 base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.4-3zZS9Lb71u1HvtEFsqAO3S
    casa-types-0.0.3-1xUlv8giMsO8NDsABxC9jx
    conduit-1.3.6.1-4sdnvTzdBma5YgRtH9r4P9
    conduit-extra-1.3.8-JsZlK7bbP5W8Y5cbrIEDfl containers-0.6.7
    crypton-1.0.4-4tCArmqzb3m53iwYBOQdXY
    crypton-conduit-0.2.3-Bes73DPfOq5Cv73YbS8xxR
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.9-JQkwHpbholZIa3smKixdXr
    generic-deriving-1.14.7-EdpMS6VUjSWAYwhkxCiLC8
    hackage-security-0.6.3.2-EteSo2rCEyfBgZK8Gq7yPv
    hpack-0.38.0-KOmM34DQAsaE0LmCeIS5dK
    http-client-0.7.19-CdoyGBdmx4CJG3r6obV7W1
    http-client-tls-0.3.6.4-AnHGLSahOg9HVl4h6a2CCE
    http-conduit-2.3.9.1-IhIEGxcJ0jxNTiAgdkscf
    http-download-0.2.1.0-C4tfoLmnSrL1CHmLsXsoza
    http-types-0.12.4-7VF1fWYoZaw5btElYXN8F2
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-GaZ2e74kZTJHR0YFZY0APg
    path-0.9.6-1wADnfQAZA99zoAP25QpzT
    path-io-1.8.2-JDcPEuOdkzSBrE8uogAd7a
    persistent-2.14.6.0-KQ5ms5DpPkNLF00rBKfpso
    persistent-sqlite-2.13.2.0-I0cJy0dYei53o6PDgwnYK2
    primitive-0.9.1.0-4hlhnHtP0gACqmGq3bJZxL
    resourcet-1.3.0-xQkQK6AKd8CwOHTJH07Rv
    rio-0.1.24.0-JBW6BaHiyub4m2SBTmJfNr
    rio-orphans-0.1.2.0-CrBkAq92h806W5MdgDQQHc
    rio-prettyprint-0.1.8.0-Dz1o41B5IBnB46DkvbtCI0
    tar-conduit-0.4.1-7BFEyJEnAOoGsRtCDAzz2 text-2.0.2
    text-metrics-0.3.3-3TWDwrwAO4D6rSKlVj0EfL time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-Ihfe6doCANm1TVMx2D80dC
    unliftio-0.2.25.1-HBz9luDISr2DkipcdISm26
    unordered-containers-0.2.21-A5j6YbVJ6iQ4Gx0hziy0Dr
    vector-0.13.2.0-HIEoUaJKlQrG3qeQBTxJjw
    yaml-0.11.11.2-9piUJVvEUYuG0CUDTmcMvP
    zip-archive-0.4.3.2-9uTxSUznKixFfAkalbVnMD

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

